@@ -2,4 +2,4 @@
 
 from .version import __version__
 from .entry import PipenCliRunPlugin
-from .pipeline import Pipeline
+from .pipeline import Pipeline, process
